/* kmp3te.h

  Created by SMF aka Antoine Laydier (laydier@usa.net)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _KMP3TE_H_
#define _KMP3TE_H_

/*=============================================================================
  HEADERs
 ============================================================================*/
#include <drag.h>
#include <qlistbox.h>
#include <kpanner.h>
#include <kmenubar.h>
#include <ktopwidget.h>
#include "widgets.h"

/*=============================================================================
  CLASS
 ============================================================================*/

/**
 * This is the class TopLevel. The class contains the definition of the
 * main window of the application Kmp3te
 *
 * @short Main Window class for Kmp3te
 * @author Antoine Laydier (smf@mail.dotcom.fr)
 * @version 0.4.2
 *
 */
class TopLevel : public KTopLevelWidget
{
  Q_OBJECT;
  
 public:
  
  enum {  MENU_ID_ABOUT = 100 , MENU_ID_OPEN  = 10,
	  MENU_ID_QUIT  = 20  , MENU_ID_HELP  = 30 
       };
    
  /**
   * The constructor method for class TopLevel
   *
   * @see TopLevel
   * @param sfolder Folder page number to open first
   *
   */
  TopLevel( int sfolder=0);

  /**
   * The destrucor method for class TopLevel
   *
   */
  ~TopLevel( );

  /**
   * Handels the close event of the main window of Kmp3te
   *
   */
  void  closeEvent( QCloseEvent *e );
  /**
   * This method allow to modify the process of and event in order
   * to skip a part of it 
   *
   */
  void  setHack( void ) { hack = TRUE; } 

 protected:

  /**
   * Handles all the resizing of the main window of Kmp3te
   *
   * @param all if this is false the widgets won't be resized but the
   * widget will be updated
   *
   */
  virtual void resizeEvent(QResizeEvent *);
  
  /**
   * This function is used to save the state of the program in order
   * to restart it in the same state
   */
  void saveSettings( void );
  
  QPopupMenu   *file, *help;
  KMenuBar     *menubar;
  KPanner      *panner;        
  QListBox     *fileList;
  TagEditor    *tagEditor;   
  KDNDDropZone *DNDZone;        // to allow drop n drop
  
  bool          hack;           // for hacking event :P
  
 protected slots:
    
  /**
   * Handles the menu events and dispatch them
   *
   * @param id the option of the menu choose
   */
  void menuHandler(int id);

  /**
   * Quit the application
   */
  void quitSlot();

  /**
   * Handles the move of the Menubar
   */
  void menuMove(void);

  /**
   * Handles the move of the Panner
   */
  void pannerMove(void);

  /**
   * Handles the drop of files in the program window
   */
  void drop(KDNDDropZone *);
};

#endif
